BoolExtensions extension

Contains boolean's extension methods for custom assertions in unit tests.

on

Properties

should → BoolAssertions

Available on bool?, provided by the BoolExtensions extension

Returns an BoolAssertions object that can be used to assert the current bool />.
no setter